@@ -32,6 +32,7 @@ from PyQt5.QtWidgets import (
     QAction,
     QApplication,
     QLabel,
+    QLineEdit,
     QMenu,
     QTreeView,
     QVBoxLayout,
@@ -47,7 +48,6 @@ from PyQt5.QtGui import (
 import app
 import job
 import signals
-from widgets.lineedit import LineEdit
 
 
 # List of notation fonts currently installed.
@@ -67,7 +67,7 @@ class TextFontsWidget(QWidget):
 
         self.status_label = QLabel(wordWrap=True)
         self.tree_view = tv = QTreeView()
-        self.filter_edit = LineEdit()
+        self.filter_edit = QLineEdit(clearButtonEnabled=True)
         tv.setEditTriggers(QAbstractItemView.NoEditTriggers)
         tv.setContextMenuPolicy(Qt.CustomContextMenu)
         tv.customContextMenuRequested.connect(self.show_context_menu)
@@ -492,7 +492,7 @@ class TextFonts(QObject):
         """Parse the LilyPond log and push entries to the various
         lists and dictionaries. Parsing the actual font style
         definition is deferred to add_style_to_family()."""
-        regexp = re.compile('(.*)\\-\d+')
+        regexp = re.compile(r'(.*)\\-\d+')
         families = {}
         config_files = []
         config_dirs = []
